@@ -1,13 +1,16 @@
-import requests
+"""Fetch YouTube URL information using the public API."""
 from typing import Tuple
+
+import requests
 from bs4 import BeautifulSoup
-from .helpers import is_valid_url
-from .scraper import YouTubeScraped
+
 from music_metadata_extractor.models import BaseProviderInput
 
+from .scraper import YouTubeScraped
+
 
 def get_info(url: str) -> Tuple[BaseProviderInput, dict]:
-    """Generate provider input object for YouTube URL"""
+    """Generate provider input object for YouTube URL."""
     session = requests.Session()
 
     # In case of shortened links, get the original link
@@ -17,9 +20,6 @@ def get_info(url: str) -> Tuple[BaseProviderInput, dict]:
     main_response = requests.get(main_url)
     soup = BeautifulSoup(main_response.content, "lxml")
 
-    if not is_valid_url(soup):
-        raise ValueError("Video unavailable!")
-
     try:
         scraped_data = YouTubeScraped(main_url, soup)
         return scraped_data.scrape_yt()
